'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var preact = require('preact');
var reshapePreactComponents = require('reshape-preact-components');
var marked = _interopDefault(require('marked'));
var Image = _interopDefault(require('@hashicorp/hashi-image'));
var Button = _interopDefault(require('@hashicorp/hashi-button'));

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function SplitCta(_ref) {
  var _data = _ref._data,
      ga_prefix = _ref.ga_prefix;

  var data = reshapePreactComponents.decode(_data);
  return preact.h(
    'div',
    { 'class': 'g-split-cta' },
    data.map(function (section) {
      return preact.h(
        'div',
        {
          key: section.title || section.description,
          'class': 'g-split-cta-section',
          style: section.background_color && section.background_color.hex && 'background-color: ' + section.background_color.hex
        },
        section.background_image && preact.h(Image, {
          classes: 'bg',
          src: section.background_image.url,
          svg: section.background_image.format === 'svg',
          alt: section.background_image.alt
        }),
        section.title_logo && preact.h(
          'div',
          { 'class': 'logo' },
          preact.h(Image, {
            src: section.title_logo.url,
            svg: section.title_logo.format === 'svg',
            alt: section.title_logo.alt
          })
        ),
        section.title && preact.h(
          'h1',
          null,
          section.title
        ),
        section.description && preact.h('div', {
          'class': 'description',
          dangerouslySetInnerHTML: {
            __html: marked(section.description)
          }
        }),
        preact.h('div', { 'class': 'flex-grow' }),
        section.buttons && preact.h(
          'div',
          { 'class': 'buttons' },
          section.buttons.map(function (button) {
            if (ga_prefix) button.ga_prefix = ga_prefix;
            return preact.h(Button, _extends({ key: button.url }, button));
          })
        )
      );
    })
  );
}

module.exports = SplitCta;
